@@ -349,8 +349,10 @@ def describe_type(x):
     return class_name
 
 
-def describe_value(x, clip=50):
-    ''' Describes an object, for use in the error messages. '''
+def describe_value(x, clip=80):
+    ''' Describes an object, for use in the error messages. 
+        Short description, no multiline.
+    '''
     if hasattr(x, 'shape') and hasattr(x, 'dtype'):
         shape_desc = 'x'.join(str(i) for i in x.shape)
         desc = 'array[%r](%s) ' % (shape_desc, x.dtype)
@@ -363,3 +365,20 @@ def describe_value(x, clip=50):
         return remove_newlines(final)
 
 
+def describe_value_multiline(x):
+    ''' Describes an object, for use in the error messages. '''
+    if hasattr(x, 'shape') and hasattr(x, 'dtype'):
+        shape_desc = 'x'.join(str(i) for i in x.shape)
+        desc = 'array[%r](%s) ' % (shape_desc, x.dtype)
+        final = desc + '\n', x.__repr__()
+        return final
+    else:
+        class_name = describe_type(x)
+        # TODO: add all types
+        desc = 'Instance of %s.' % class_name
+        final = desc +'\n' + x.__repr__()
+#         final = desc +'\n' +str(x)
+        return final
+
+
+
